==> ugene_1.31.1+dfsg.orig.tar.xz: ugene-1.31.1/src/plugins_3rdparty/gor4/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="34"/>
        <source>GORIV</source>
        <translation>GORIV</translation>
    </message>
</context>
<context>
    <name>SecStructPredictTask</name>
    <message>
        <source>seq database not found</source>
        <translation type="vanished">Sequence database not found</translation>
    </message>
    <message>
        <source>observed structures database not found</source>
        <translation type="vanished">observed structures database not found</translation>
    </message>
    <message>
        <source>sequence is too long, max seq size is 10000</source>
        <translation type="vanished">Too long input sequence: maximum allowed length is 10000</translation>
    </message>
</context>
<context>
    <name>U2::GorIVAlgTask</name>
    <message>
        <location filename="../src/gor.cpp" line="151"/>
        <source>%1 errors</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/gor.cpp" line="227"/>
        <source>The value of MAXRES should be increased: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/gor.cpp" line="237"/>
        <source>protein: %1 residue: %2
Invalid amino acid type or secondary structure state : ==&gt;%3&lt;==</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/gor.cpp" line="553"/>
        <source>Error invalid value of np= %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::SecStructPredictPlugin</name>
    <message>
        <location filename="../src/GorIVPlugin.cpp" line="51"/>
        <source>GORIV</source>
        <translation>GORIV</translation>
    </message>
    <message>
        <location filename="../src/GorIVPlugin.cpp" line="51"/>
        <source>GORIV protein secondary structure prediction</source>
        <translation>Предсказание вторичной структуры протеинов GORIV</translation>
    </message>
</context>
<context>
    <name>U2::SecStructPredictTask</name>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="50"/>
        <source>seq database not found</source>
        <translation>Sequence database not found</translation>
    </message>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="56"/>
        <source>observed structures database not found</source>
        <translation>observed structures database not found</translation>
    </message>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="63"/>
        <source>sequence is too long, max seq size is 10000</source>
        <translation>Too long input sequence: maximum allowed length is 10000</translation>
    </message>
</context>
</TS>

==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/plugins_3rdparty/gor4/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>QObject</name>
    <message>
        <source>GORIV</source>
        <translation type="vanished">GORIV</translation>
    </message>
</context>
<context>
    <name>SecStructPredictTask</name>
    <message>
        <source>seq database not found</source>
        <translation type="vanished">Sequence database not found</translation>
    </message>
    <message>
        <source>observed structures database not found</source>
        <translation type="vanished">observed structures database not found</translation>
    </message>
    <message>
        <source>sequence is too long, max seq size is 10000</source>
        <translation type="vanished">Too long input sequence: maximum allowed length is 10000</translation>
    </message>
</context>
<context>
    <name>U2::GorIVAlgTask</name>
    <message>
        <location filename="../src/gor.cpp" line="151"/>
        <source>%1 errors</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/gor.cpp" line="227"/>
        <source>The value of MAXRES should be increased: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/gor.cpp" line="237"/>
        <source>protein: %1 residue: %2
Invalid amino acid type or secondary structure state : ==&gt;%3&lt;==</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/gor.cpp" line="553"/>
        <source>Error invalid value of np= %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::SecStructPredictPlugin</name>
    <message>
        <location filename="../src/GorIVPlugin.cpp" line="51"/>
        <source>GORIV</source>
        <translation>GORIV</translation>
    </message>
    <message>
        <location filename="../src/GorIVPlugin.cpp" line="51"/>
        <source>GORIV protein secondary structure prediction</source>
        <translation>Предсказание вторичной структуры протеинов GORIV</translation>
    </message>
</context>
<context>
    <name>U2::SecStructPredictTask</name>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="50"/>
        <source>seq database not found</source>
        <translation>Sequence database not found</translation>
    </message>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="56"/>
        <source>observed structures database not found</source>
        <translation>observed structures database not found</translation>
    </message>
    <message>
        <location filename="../src/GorIVAlgTask.cpp" line="63"/>
        <source>sequence is too long, max seq size is 10000</source>
        <translation>Too long input sequence: maximum allowed length is 10000</translation>
    </message>
</context>
</TS>
